<?php

namespace Assetdocs\Depart\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Depart\Interfaces\DepartRepositoryInterface;

class DepartController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Depart\Interfaces\DepartRepositoryInterface $depart
     *
     * @return type
     */
    public function __construct(DepartRepositoryInterface $depart)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $depart;
        parent::__construct();
    }

    /**
     * Show depart's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $departs = $this->repository
            ->pushCriteria(new \Assetdocs\Depart\Repositories\Criteria\DepartPublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('depart::public.depart.index', compact('departs'))->render();
    }

    /**
     * Show depart.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $depart = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('depart::public.depart.show', compact('depart'))->render();
    }
}
